/*  format.h - format module definitions
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __FORMAT_H__
#define __FORMAT_H__

#include <stdio.h>

typedef struct {
  char   *name;                     /* format name, specified on command line in certain modes */
  char   *description;              /* one line description of this format */
  char   *extension;                /* extension to append to files created by this module */
  int     is_compressed;            /* is this file format a compression format? */
  int     needs_external_program;   /* does this module rely on an external program to function? */
  char   *external_program;         /* name of external program, if necessary */
  int   (*is_our_file)(char *);     /* routine to determine whether the given file belongs to this format plugin */
  int     supports_input;           /* is input supported for this file format? */
  FILE *(*open_input)(char *);      /* routine to open a file of this format for input */
  int     supports_output;          /* is output supported for this file format? */
  FILE *(*open_output)(char *);     /* routine to open a file of this format for output */
} format_module;

#endif
