/*  core_fileio.c - file I/O functions
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include "shntool.h"

int read_n_bytes(FILE *in,unsigned char *buf,int num)
/* reads the specified number of bytes from the file descriptor 'in' into buf */
{
  int read;
  if ((read = fread(buf,1,num,in)) != num)
    error("tried to read %d bytes, but only read %d - possible corrupt file",num,read);
  return read;
}

int write_n_bytes(FILE *out,unsigned char *buf,int num)
/* writes the specified number of bytes from buf into the file descriptor 'out' */
{
  int wrote;
  if ((wrote = fwrite(buf,1,num,out)) != num) {
    error("tried to write %d bytes, but only wrote %d - make sure that:\n"
          "  - there is enough disk space\n"
          "  - the specified output directory exists\n"
          "  - you have permission to create files in the output directory",num,wrote);
  }
  return wrote;
}

unsigned long transfer_n_bytes(FILE *in,FILE *out,unsigned long bytes)
/* transfers 'bytes' bytes from file descriptor 'in' to file descriptor 'out' */
{
  unsigned char buf[XFER_SIZE];
  int bytes_to_xfer,
      actual_bytes_read,
      actual_bytes_written;
  unsigned long total_bytes_to_xfer = bytes,
                total_bytes_xfered = 0;

  while (total_bytes_to_xfer > 0) {
    bytes_to_xfer = min(total_bytes_to_xfer,XFER_SIZE);
    actual_bytes_read = read_n_bytes(in,buf,bytes_to_xfer);
    actual_bytes_written = write_n_bytes(out,buf,actual_bytes_read);
    total_bytes_xfered += (unsigned long)actual_bytes_written;
    if (actual_bytes_read != bytes_to_xfer || actual_bytes_written != bytes_to_xfer)
      break;
    total_bytes_to_xfer -= bytes_to_xfer;
  }
  return total_bytes_xfered;
}

int read_le_long(FILE * file, unsigned long *ret)
/* reads an unsigned long in little-endian format from a file descriptor */
{
  unsigned char buf[4];

  if (fread(buf, 1, 4, file) != 4)
    return 0;

  *ret = (buf[3] << 24) | (buf[2] << 16) | (buf[1] << 8) | buf[0];
  return 1;
}

int read_le_short(FILE * file, unsigned short *ret)
/* reads an unsigned short in little-endian format from a file */
{
  unsigned char buf[2];

  if (fread(buf, 1, 2, file) != 2)
    return 0;

  *ret = (buf[1] << 8) | buf[0];
  return 1;
}
