/*  core_output.c - generic output functions
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include "shntool.h"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

static char msgbuf[BUF_SIZE];

void error(char *msg, ...)
{
  va_list args;
  int line = 0,
      not_an_error = 0;
  char prefix[128],
       *head, *tail;

  va_start(args,msg);

  if (msg[0] == '\0')
    not_an_error = 1;

#ifdef HAVE_VSNPRINTF
  vsnprintf(msgbuf,BUF_SIZE-1,msg+not_an_error,args);
#else
  vsprintf(msgbuf,msg+not_an_error,args);
#endif

  if (1 == aliased || NULL == progmode)
#ifdef HAVE_SNPRINTF
    snprintf(prefix,127,"%s: ",progname);
#else
    sprintf(prefix,"%s: ",progname);
#endif
  else
#ifdef HAVE_SNPRINTF
    snprintf(prefix,127,"%s [%s]: ",progname,progmode);
#else
    sprintf(prefix,"%s [%s]: ",progname,progmode);
#endif

  head = tail = msgbuf;
  while (*head != '\0') {
    if (*head == '\n') {
      *head = '\0';
      fprintf(stderr,"%s%s%s\n",prefix,(1 == not_an_error)?"":((0 == (line++) && strlen(tail) > 0)?"error: ":"       "),tail);
      tail = head + 1;
    }
    head++;
  }
  fprintf(stderr,"%s%s%s\n",prefix,(1 == not_an_error)?"":((0 == line)?"error: ":"       "),tail);

  va_end(args);
}
