/*  format_kxs.c - kexis format module
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <string.h>
#include "format.h"
#include "fileio.h"
#include "misc.h"

#define KEXIS "kexis"

char *unkxs_args[5] = {KEXIS, "-s", NULL, NULL};      /* arguments for unkexising */

FILE *open_input_kxs(char *);
FILE *open_output_kxs(char *);
int is_kxs_file(char *);

format_module format_kxs = {
  "kxs",
  "kexis lossless WAV file compressor (EXPERIMENTAL)",
  "kxs",
  1,
  1,
  KEXIS,
  is_kxs_file,
  1,
  open_input_kxs,
  0,
  open_output_kxs
};

int run_kexis(char **args,FILE **input,FILE**output)
{
  return spawn(KEXIS,args,input,output);
}

FILE *open_input_kxs(char *filename)
{
  FILE *input,*output;
  int pid;

  unkxs_args[2] = filename;
  pid = run_kexis(unkxs_args,&input,&output);

  if (output)
    fclose(output);

  return input;
}

FILE *open_output_kxs(char *filename)
/* currently unsupported due to the design of kexis (it doesn't accept data on stdin) */
{
  return NULL;
}

int is_kxs_file(char *filename)
{
  FILE *file;
  unsigned char buf[4];

  if (NULL == (file = fopen(filename, "rb")))
    return 0;

  if (4 != fread(buf,1,4,file)) {
    fclose(file);
    return 0;
  }
  fclose(file);

  if (0 == strncmp(buf,"KEXS",4))
    return 1;

  /* it's not a KXS */
  return 0;
}
