/*  format_shn.c - shorten format module
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <string.h>
#include "format.h"
#include "fileio.h"
#include "misc.h"

#define SHORTEN "shorten"

char *unshn_args[5] = {SHORTEN, "-x", NULL, "-", NULL},                      /* arguments for unshortening */
     *shn_args[8] = {SHORTEN, "-n", "256", "-r", "32.0", "-", NULL, NULL};   /* arguments for shortening   */

FILE *open_input_shn(char *);
FILE *open_output_shn(char *);
int is_shn_file(char *);

format_module format_shn = {
  "shn",
  "shorten low complexity waveform coder",
  "shn",
  1,
  1,
  SHORTEN,
  is_shn_file,
  1,
  open_input_shn,
  1,
  open_output_shn
};

int run_shorten(char **args,FILE **input,FILE**output)
{
  return spawn(SHORTEN,args,input,output);
}

FILE *open_input_shn(char *filename)
{
  FILE *input,*output;
  int pid;

  unshn_args[2] = filename;
  pid = run_shorten(unshn_args,&input,&output);

  if (output)
    fclose(output);

  return input;
}

FILE *open_output_shn(char *filename)
{
  FILE *input,*output;
  int pid;

  shn_args[6] = filename;
  pid = run_shorten(shn_args,&input,&output);

  if (input)
    fclose(input);

  return output;
}

int is_shn_file(char *filename)
{
  FILE *file;
  unsigned char buf[4];

  if (NULL == (file = fopen(filename, "rb")))
    return 0;

  if (4 != fread(buf,1,4,file)) {
    fclose(file);
    return 0;
  }
  fclose(file);

  if (0 == strncmp(buf,"ajkg",4))
    return 1;

  /* it's not a SHN */
  return 0;
}
